@@ -18,7 +18,8 @@ async def get_date(call: types.CallbackQuery):
 async def get_datetime(msg: types.Message, state: FSMContext):
     await msg.answer(text=str(await dtm.get_datetime(text=msg.text, state=state)))
 
-dm = DateManager(router=dp, callback=get_date, open_on_filter=Text(text='/date'))
-dtm = DatetimeManager(router=dp, callback=get_datetime, open_on_filter=Text(text='/datetime'))
+dm = DateManager(router=dp, callback=get_date)
+dtm = DatetimeManager(router=dp, callback=get_datetime)
+dp.message.register(dm.show_calendar_msg, Text(text='/start'))
 
 asyncio.run(dp.run_polling(bot))
\ No newline at end of file
