@@ -13,9 +13,10 @@ class TimeManagersStates(StatesGroup):
 
 class DateManager:
 
-    def __init__(self, router: Router, callback: typing.Awaitable):
+    def __init__(self, router: Router, callback: typing.Awaitable, delete_msg: bool = True):
         self._router = router
         self._callback = callback
+        self._delete_msg = delete_msg
 
         self._router.callback_query.register(self._show_date, Text(text_startswith='show_date'))
         self._router.callback_query.register(self._it_is, Text(text_startswith='it_is_'))
@@ -49,11 +50,15 @@ class DateManager:
         await call.message.edit_reply_markup(reply_markup=date_kb(self.get_prefix(), year, month))
 
     async def show_calendar_msg(self, msg: types.Message):
+        if self._delete_msg:
+            await msg.delete()
         text = '<b>🗓 Выберите дату</b>'
         kb = date_kb(self.get_prefix())
         await msg.answer(text=text, reply_markup=kb, parse_mode='html')
 
     async def show_calendar_callback(self, call: types.CallbackQuery):
+        if self._delete_msg:
+            await call.message.delete()
         text = '<b>🗓 Выберите дату</b>'
         kb = date_kb(self.get_prefix())
         await call.message.answer(text=text, reply_markup=kb, parse_mode='html')
